import os
from pathlib import Path

import axipy as axp
from PySide2.QtCore import Qt
from PySide2.QtWidgets import QDialog, QFileDialog, QDialogButtonBox, QMessageBox

from .ui.form import Ui_Dialog


class Form(QDialog):
    def __init__(self):
        super().__init__(axp.view_manager.global_parent)
        self._ui = Ui_Dialog()
        self._ui.setupUi(self)
        self.btn_ok = self._ui.buttonBox.button(QDialogButtonBox.Ok)
        self.setWindowFlags(self.windowFlags() & ~Qt.WindowContextHelpButtonHint)  # Выключение значка "?"

        self._ui.cmb_tables.addItems(t.name for t in axp.data_manager.tables)
        self._ui.btn_select_folder.clicked.connect(self.on_select_folder_clicked)
        self._ui.le_folder.textChanged.connect(self.do_enable)
        self.accepted.connect(self.make_mif)

        self.do_enable()

    def on_select_folder_clicked(self):
        fld = QFileDialog.getExistingDirectory(self, "Выберите папку")
        if fld:
            with os.scandir(fld) as sd:
                if any(sd) \
                        and QMessageBox.question(
                        self,
                        "Выбор папки",
                        "Выбранная папка не пуста.\nДанные могут быть перезаписаны. Продолжить?",
                        buttons=QMessageBox.StandardButton.Yes | QMessageBox.StandardButton.No) != QMessageBox.Yes:
                    return
            self._ui.le_folder.setText(fld)

        self.do_enable()

    def do_enable(self):
        if self._ui.cmb_tables.currentText() and self._ui.le_folder.text():
            self.btn_ok.setEnabled(True)
        else:
            self.btn_ok.setEnabled(False)

    def make_mif(self):
        try:
            tbl = next(t for t in axp.data_manager.tables if t.name == self._ui.cmb_tables.currentText())
            fld = Path(self._ui.le_folder.text())

            for i, r in enumerate(tbl.items()):
                print(i, r)
                dst = axp.provider_manager.mif.get_destination(str(fld.joinpath(f'{i}.mif')), tbl.schema)
                dst.export([r])

        except Exception as err:
            msg = QMessageBox(QMessageBox.Warning, self.windowTitle(), "Произошла ошибка при создании MIF",
                              buttons=QMessageBox.StandardButton.Ok, parent=self)
            msg.setDetailedText(str(err))
            msg.open()
            return False
